src/main/java/de/uapcore/lightpit/Constants.java

changeset 74
91d1fc2a3a14
parent 71
dca186d3911f
child 78
bb4c52bf3439
--- a/src/main/java/de/uapcore/lightpit/Constants.java	Fri May 22 17:19:09 2020 +0200
+++ b/src/main/java/de/uapcore/lightpit/Constants.java	Fri May 22 17:26:27 2020 +0200
@@ -36,11 +36,15 @@
  * Constants with (class) local scope are defined in their respective classes.
  */
 public final class Constants {
+    /**
+     * The path where the JSP files reside.
+     */
     public static final String JSP_PATH_PREFIX = "/WEB-INF/jsp/";
 
-    public static final String DYN_FRAGMENT_PATH_PREFIX = "/WEB-INF/dynamic_fragments/";
-
-    public static final String DYN_FRAGMENT_COMMIT_SUCCESSFUL = "commit-successful";
+    /**
+     * The name of the generic JSP page that is displayed after a successful commit.
+     */
+    public static final String JSP_COMMIT_SUCCESSFUL = "commit-successful";
 
     /**
      * Name for the context parameter specifying the available languages.
@@ -83,9 +87,9 @@
     public static final String REQ_ATTR_PATH = fqn(AbstractLightPITServlet.class, "path");
 
     /**
      * Key for the name of the fragment which should be rendered.
      */
-    public static final String REQ_ATTR_FRAGMENT = fqn(AbstractLightPITServlet.class, "fragment");
+    public static final String REQ_ATTR_CONTENT_PAGE = fqn(AbstractLightPITServlet.class, "content-page");
 
     /**
      * Key for the name of the additional stylesheet used by a module.
@@ -83,9 +87,9 @@
 
     /**
-     * Key for the name of the fragment which should be rendered.
+     * Key for the name of the page which should be rendered.
      */

mercurial